@@ -58,7 +58,7 @@ Theta <- list(pdf1 = "gamma",
   theta1.1 = c(1/20, 1, 1/20),
   theta2.1 = c(40, 6, 200))
 
-gamma3 <- RNGMIX(Dataset.name = "gamma3", n = n, Theta = Theta)
+gamma3 <- RNGMIX(Dataset.name = "gamma3", rseed = -4, n = n, Theta = Theta)
 
 
 ###################################################
@@ -67,25 +67,23 @@ gamma3 <- RNGMIX(Dataset.name = "gamma3", n = n, Theta = Theta)
 ## Estimate number of components, component weights and component parameters.
 
 gamma1est <- REBMIX(Dataset = gamma1@Dataset,
-  Preprocessing = "histogram",
+  Preprocessing = "Parzen window",
   cmax = 8,
   Criterion = c("AIC", "BIC"),
-  pdf = "gamma",
-  K = 30:80)
+  pdf = "gamma")
 
 gamma2est <- REBMIX(Dataset = gamma2@Dataset,
   Preprocessing = "histogram",
   cmax = 8,
   Criterion = "BIC",
-  pdf = "gamma",
-  K = 30:80)
+  pdf = "gamma")
 
 gamma3est <- REBMIX(Dataset = gamma3@Dataset,
   Preprocessing = "histogram",
   cmax = 8,
   Criterion = "BIC",
   pdf = "gamma",
-  K = 30:80)
+  K = 23:27)
 
 
 ###################################################
@@ -99,7 +97,7 @@ plot(gamma3est, pos = 1, what = c("den", "dis"), ncol = 2, npts = 1000)
 ###################################################
 summary(gamma2est)
 
-coef(gamma3est)
+coef(gamma1est, pos = 2)
 
 
 ###################################################
@@ -144,7 +142,7 @@ poisson <- RNGMIX(Dataset.name = paste("Poisson_", 1:10, sep = ""), n = n, Theta
 
 poissonest <- REBMIX(Dataset = poisson@Dataset,
   Preprocessing = "histogram",
-  cmax = 6,
+  cmax = 10,
   Criterion = "MDL5",
   pdf = rep("Poisson", 2),
   K = 1)
@@ -153,7 +151,7 @@ poissonest <- REBMIX(Dataset = poisson@Dataset,
 ###################################################
 ### code chunk number 10: poisson-fig
 ###################################################
-plot(poissonest, pos = 7, what = c("dens", "marg", "IC", "D", "logL"), nrow = 2, ncol = 3, npts = 1000)
+plot(poissonest, pos = 9, what = c("dens", "marg", "IC", "D", "logL"), nrow = 2, ncol = 3, npts = 1000)
 
 
 ###################################################
@@ -185,42 +183,35 @@ data("wreath", package = "mclust")
 ###################################################
 ## Estimate number of components, component weights and component parameters.
 
-n <- nrow(wreath)
-
-K <- c(as.integer(1 + log2(sum(n))), # Minimum v follows the Sturges rule.
-  as.integer(2 * sum(n)^0.5)) # Maximum v follows the RootN rule.
-
 wreathest <- REBMIX(model = "REBMVNORM",
   Dataset = list(as.data.frame(wreath)),
   Preprocessing = "histogram",
   cmax = 20,
-  Criterion = "BIC",
-  pdf = rep("normal", ncol(wreath)),
-  K = K[1]:K[2])
+  Criterion = "BIC")
 
 
 ###################################################
-### code chunk number 15: rebmix-code
-###################################################
-summary(wreathest)
-
-coef(wreathest)
-
-
-###################################################
-### code chunk number 16: wreath-fig
+### code chunk number 15: wreath-fig
 ###################################################
 plot(wreathest)
 
 
 ###################################################
-### code chunk number 17: wreath-clu-fig
+### code chunk number 16: wreath-clu-fig
 ###################################################
 wreathclu <- RCLRMIX(model = "RCLRMVNORM", x = wreathest)
 
 plot(wreathclu, s = 14)
 
 
+###################################################
+### code chunk number 17: rebmix-code
+###################################################
+summary(wreathest)
+
+coef(wreathest)
+
+
 ###################################################
 ### code chunk number 18: rebmix-code
 ###################################################
@@ -238,40 +229,33 @@ data("Baudry_etal_2010_JCGS_examples", package = "mclust")
 ###################################################
 ## Estimate number of components, component weights and component parameters.
 
-n <- nrow(ex4.1)
-
-K <- c(as.integer(1 + log2(sum(n))), # Minimum v follows the Sturges rule.
-  as.integer(2 * sum(n)^0.5)) # Maximum v follows the RootN rule.
-
 ex4.1est <- REBMIX(model = "REBMVNORM",
   Dataset = list(as.data.frame(ex4.1)),
   Preprocessing = "Parzen window",
   cmax = 10,
-  Criterion = "AIC",
-  pdf = rep("normal", ncol(ex4.1)),
-  K = K[1]:K[2])
+  Criterion = "AIC")
 
 
 ###################################################
-### code chunk number 21: rebmix-code
-###################################################
-summary(ex4.1est)
-
-
-###################################################
-### code chunk number 22: ex4_1-fig
+### code chunk number 21: ex4_1-fig
 ###################################################
 plot(ex4.1est, pos = 1, what = c("dens"), nrow = 1, ncol = 1)
 
 
 ###################################################
-### code chunk number 23: ex4_1-clu-fig
+### code chunk number 22: ex4_1-clu-fig
 ###################################################
 ex4.1clu <- RCLRMIX(model = "RCLRMVNORM", x = ex4.1est)
 
 plot(ex4.1clu)
 
 
+###################################################
+### code chunk number 23: rebmix-code
+###################################################
+summary(ex4.1est)
+
+
 ###################################################
 ### code chunk number 24: rebmix-code
 ###################################################
@@ -294,20 +278,11 @@ Iris <- split(p = 0.75, Dataset = iris, class = 5)
 # Estimate number of components, component weights and component
 # parameters for train subsets.
 
-n <- range(Iris@ntrain)
-
-K <- c(as.integer(1 + log2(n[1])), # Minimum v follows Sturges rule.
-  as.integer(10 * log10(n[2]))) # Maximum v follows log10 rule.
-
-K <- c(floor(K[1]^(1/4)), ceiling(K[2]^(1/4)))
-
 irisest <- REBMIX(model = "REBMVNORM",
   Dataset = Iris@train,
   Preprocessing = "Parzen window",
   cmax = 10,
-  Criterion = "ICL-BIC",
-  pdf = rep("normal", 4),
-  K = K[1]:K[2])
+  Criterion = "ICL-BIC")
 
 
 ###################################################
@@ -322,21 +297,21 @@ iriscla <- RCLSMIX(model = "RCLSMVNORM",
 
 
 ###################################################
-### code chunk number 27: iris-cla-fig
-###################################################
-# Plot selected features.
-
-plot(iriscla, nrow = 3, ncol = 2)
-
-
-###################################################
-### code chunk number 28: rebmix-code
+### code chunk number 27: rebmix-code
 ###################################################
 iriscla
 
 summary(iriscla)
 
 
+###################################################
+### code chunk number 28: iris-cla-fig
+###################################################
+# Plot selected features.
+
+plot(iriscla, nrow = 3, ncol = 2)
+
+
 ###################################################
 ### code chunk number 29: rebmix-code
 ###################################################
@@ -400,21 +375,21 @@ adultcla <- BFSMIX(x = adultest,
 
 
 ###################################################
-### code chunk number 34: adult-cla-fig
-###################################################
-# Plot selected chunks.
-
-plot(adultcla, nrow = 5, ncol = 2)
-
-
-###################################################
-### code chunk number 35: rebmix-code
+### code chunk number 34: rebmix-code
 ###################################################
 adultcla
 
 summary(adultcla)
 
 
+###################################################
+### code chunk number 35: adult-cla-fig
+###################################################
+# Plot selected chunks.
+
+plot(adultcla, nrow = 5, ncol = 2)
+
+
 ###################################################
 ### code chunk number 36: rebmix-code
 ###################################################
